% Laboratoire de Vibration et d'Acoustic McGill University
% by Mathias LEGRAND 30.03.06

\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{book}}
\ProcessOptions

\LoadClass[a4paper]{book}
\RequirePackage[T1]{fontenc}
\RequirePackage[latin1]{inputenc}
\RequirePackage{graphicx}
\RequirePackage[dvips]{xcolor}
\RequirePackage{fancyhdr}
\RequirePackage{fancybox}
\RequirePackage{amsmath}
\RequirePackage{amssymb}
\RequirePackage{amsfonts}
%\RequirePackage{amscd}
\RequirePackage{subfigure}
% \RequirePackage{nameref}
% \RequirePackage{multirow}
\RequirePackage{array}
%\RequirePackage[square,numbers]{natbib}
%\RequirePackage{lmodern}
\RequirePackage{rotating}
\RequirePackage[frenchb]{babel}
\frenchbsetup{IndentFirst=false}
\RequirePackage{upgreek}
\RequirePackage{pstricks-add,pst-func,pst-solides3d}

% definition de couleurs pour les liens Hyperref dans le texte
\definecolor{ocre}{RGB}{243,102,25}
\colorlet{FondFig}{gray!10}

% paramtres de la table des matires
\setcounter{tocdepth}{2}
\setcounter{secnumdepth}{2}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'entte de la table des matires
\renewcommand{\tableofcontents}{
\thispagestyle{empty}
\rput[lb](-3.5,-9){\includegraphics[width=1.01\paperwidth]{\thechapterimage}}%
\rput[lb](-0.5,-7.5){\psframebox[fillstyle=solid,fillcolor=white,linearc=25pt,%
cornersize=absolute,framesep=15pt,opacity=0.7,linewidth=2pt,linecolor=ocre]{%
\;\Huge\sffamily\bfseries\textcolor{black}{\contentsname}\vphantom{pflg}\hphantom{ploploploploploploploploplo}}}\par
\vspace*{300\p@}%
\pdfbookmark[0]{\contentsname}{tableofcontents} % table des matires dans les signets
\@starttoc{toc}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% environnement de liste
\newenvironment{maliste}%
{\begin{list}%
    {$-$}%
    {%\setlength{\labelwidth}{30pt}%
     \setlength{\leftmargin}{30pt}%
     \setlength{\itemsep}{30pt}}}%
{\end{list}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'apparence des parties
\newdimen\betweenumberspace          % dimension for space between
\betweenumberspace=5\p@               % number and text of titles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% pour crire correctement les fractions dans le texte
\newcommand*{\Sfrac}[2]{%
  \hspace*{.1em}\raisebox{.5ex}{$#1$}\hspace*{-.1em}%
  /\hspace*{-.15em}\raisebox{-.25ex}{$#2$}%
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'entte des chapitres
\newcommand{\thechapterimage}{}
\newcommand{\chapterimage}[1]{\renewcommand{\thechapterimage}{#1}}
\def\thechapter{\Roman{chapter}}
\def\@makechapterhead#1{%
\thispagestyle{empty}
  {\centering \normalfont\sffamily
    \ifnum \c@secnumdepth >\m@ne
      \if@mainmatter
      \rput[lb](-3,-9){\includegraphics[width=\paperwidth]{\thechapterimage}}
      \rput[lb](0,-7.5){\psframebox[fillstyle=solid,fillcolor=white,linearc=25pt,%
      cornersize=absolute,framesep=15pt,opacity=0.7,linewidth=2pt,linecolor=ocre]{\;\Huge\sffamily\bfseries\textcolor{black}{\thechapter\;\;---\;\;#1}\vphantom{pflg}\hphantom{ploploploploploploploploplo}}}}\par
    \vspace*{300\p@}%
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'entte des chapitres toils
\newcommand\starchapter[1]{%
    \if@openright\cleardoublepage\else\clearpage\fi
    \thispagestyle{empty}
    \rput[lb](-3.5,-9){\includegraphics[width=\paperwidth]{\thechapterimage}}
      \rput[lb](-0.5,-7.5){\psframebox[fillstyle=solid,fillcolor=white,linearc=25pt,%
      cornersize=absolute,framesep=15pt,opacity=0.7,linewidth=2pt,linecolor=ocre]{\Huge\sffamily\bfseries\textcolor{black}{#1}\vphantom{pflg}\hphantom{ploploploploploploploploplo}}}\par
    \vspace*{300\p@}%
    \markboth{\normalfont\normalsize\sffamily #1}{}
    }
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de la bibliographie
\renewenvironment{thebibliography}[1]{
\setlength{\parindent}{0cm}
\chapter*{%
\thispagestyle{empty}%
                \rput[lb](-3,-6.1){\includegraphics[width=1.01\paperwidth]{\thechapterimage}}
                \rput[lb](0,-4.6){\psframebox[fillstyle=solid,fillcolor=white,linearc=25pt,cornersize=absolute,framesep=15pt,opacity=0.7,%
                linewidth=2pt,linecolor=ocre]{\;\Huge\sffamily\bfseries\textcolor{black}{Bibliographie}\vphantom{pflg}\hphantom{ploploploploploploplploplplpoplpooploplo}}}%
                \vspace*{170\p@}}%
\markboth{\normalfont\normalsize\sffamily Rfrences}{}
\par
\phantomsection
\addcontentsline{toc}{chapter}{Bibliographie}
\list{\@biblabel{\@arabic\c@enumiv}}
{\settowidth\labelwidth{\@biblabel{#1}}}
\leftmargin\labelwidth
\setlength{\itemsep}{6pt} % augmentation de la sparation des items
\advance\leftmargin\labelsep
\@openbib@code
\usecounter{enumiv}
\let\p@enumiv\@empty
\renewcommand\theenumiv{\@arabic\c@enumiv}
\sloppy
\clubpenalty4000
\@clubpenalty \clubpenalty
\widowpenalty4000%
\sfcode`\.\@m
{\def\@noitemerr
{\@latex@warning{Empty `thebibliography' environment}}%
\endlist}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'index
\renewenvironment{theindex}{%
                \columnseprule 0.5pt%
                \columnsep 30\p@%
                \twocolumn[\@makeschapterhead{%
                \thispagestyle{empty}
                \rput[lb](-3,-7.6){\includegraphics[width=1.01\paperwidth]{\thechapterimage}}
                \rput[lb](0,-6.1){\psframebox[fillstyle=solid,fillcolor=white,linearc=25pt,cornersize=absolute,framesep=15pt,opacity=0.7,%
                linewidth=2pt,linecolor=ocre]{\;\Huge\sffamily\bfseries\textcolor{black}{Index}\vphantom{pflg}\hphantom{ploploploploploploplploplplpoplpooploplo}}}%
                \vspace*{220\p@}}]%
                \@mkboth{\normalfont\normalsize\sffamily\indexname}{\normalfont\normalsize\sffamily\indexname}%
                \thispagestyle{plain}\parindent\z@
                \parskip\z@ \@plus .3\p@\relax
                \let\item\@idxitem
                \let\item\@idxitem
                \phantomsection
                \addcontentsline{toc}{chapter}{Index}}
               {\if@restonecol\onecolumn\else\clearpage\fi}
\renewcommand\@idxitem{\par\hangindent 0\p@}
\renewcommand\subitem{\@idxitem\hspace*{10\p@}}
\renewcommand\subsubitem{\@idxitem\hspace*{20\p@}}
%\renewcommand\subsubsubitem{\@idxitem\hspace*{30\p@}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% fancyhdr parameters
\newlength\debordement\setlength\debordement{0pt}
\pagestyle{fancy}
\fancyheadoffset{\debordement}
\fancyfootoffset{\debordement}
\renewcommand{\chaptermark}[1]{\markboth{\normalfont\normalsize\sffamily #1}{}}
%\renewcommand{\sectionmark}[1]{\markright{\normalfont\normalsize\sffamily\thesection\hspace{6pt}\protect\raisebox{0.8mm}{\tiny$\bullet$}\hspace{3pt}#1}{}}
\renewcommand{\sectionmark}[1]{\markright{\normalfont\normalsize\sffamily\thesection\hspace{5pt}#1}{}}
\fancyhf{} \fancyhead[LE,RO]{\normalfont\normalsize\bfseries\sffamily\thepage}
\fancyhead[LO]{\itshape{\rightmark}}
\fancyhead[RE]{\itshape{\leftmark}}
\renewcommand{\headrulewidth}{0.5pt}
\addtolength{\headheight}{0.5pt}
\renewcommand{\footrulewidth}{0pt}
\fancypagestyle{plain}{
\fancyhead{}
\renewcommand{\headrulewidth}{0pt}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% enlve l'entte des pages de fin de chapitre si nombre de pages impair
\renewcommand{\cleardoublepage}{%
\clearpage\ifodd\c@page\else
\hbox{}
\vspace*{\fill}
\thispagestyle{empty}%
\newpage
\fi
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% dfinition de l'apparence des sections et sous-sections
\renewcommand{\@seccntformat}[1]{\llap{\textcolor{ocre}{\csname the#1\endcsname}\hspace{0.5em}}}
                                      
\renewcommand{\section}{\@startsection{section}{1}{\z@}
                       {-4ex \@plus -1ex \@minus -.4ex}%
                       {1ex \@plus.2ex }%
                       {\normalfont\Large\sffamily\bfseries}}
\renewcommand{\subsection}{\@startsection {subsection}{2}{\z@}
                          {-3ex \@plus -0.1ex \@minus -.4ex}%
                          {0.5ex \@plus.2ex }%
                          {\normalfont\fontsize{12}{16}\sffamily\bfseries}}
\renewcommand{\subsubsection}{\@startsection {subsubsection}{3}{\z@}
                          {-2ex \@plus -0.1ex \@minus -.2ex}%
                          {0.2ex \@plus.2ex }%
                          {\normalfont\fontsize{11}{16}\sffamily\bfseries}}
                          
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                    {-2ex \@plus-.2ex \@minus .2ex}%
                                    {0.1ex}%
                                    {\normalfont\fontsize{11}{13}\sffamily\bfseries}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\z@}%
                                       {-2ex \@plus-.1ex \@minus .2ex}%
                                       {0.1ex}%
                                      {\normalfont\normalsize\sffamily\bfseries}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
